@@ -1,6 +1,11 @@
 #!/bin/bash
+# This script is based on xsetup package on Berry Linux 0.64
 
-PATH="/exec:/bin:/usr/bin:/sbin:/usr/sbin"; export PATH
+# < define >
+xsetdir=/etc/X11
+
+# < init >
+PATH="/bin:/usr/bin:/sbin:/usr/sbin:/exec"; export PATH
 umask 022
 
 # [ "`id -u`" != "0" ] && echo "WARNING: $0 has to run as root to work properly." 1>&2
@@ -24,11 +29,12 @@ CYAN="[1;36m"
 # BOLD WHITE: Hint
 WHITE="[1;37m"
 
-TMPFILE="/tmp/mkxf86config-$$"
+TMPFILE="/tmp/xsetup-$$"
 MONITORTMP="$TMPFILE-monitor"
 
 rm -f "$TMPFILE" "$MONITORTMP"
 
+
 ### Utility Function(s)
 
 KVER="$(uname -r)"
@@ -36,23 +42,26 @@ KVER="$(uname -r)"
 # Reread boot command line; echo last parameter's argument or return false.
 CMDLINE="$(cat /proc/cmdline)"
 
-getbootparam(){
-case "$CMDLINE" in *\ $1=*) ;; *) return 1; ;; esac
-result="${CMDLINE##*$1=}"
-result="${result%%[     ]*}"
-echo "$result"
-return 0
+getbootparam()
+{
+	case "$CMDLINE" in *\ $1=*) ;; *) return 1; ;; esac
+	result="${CMDLINE##*$1=}"
+	result="${result%%[     ]*}"
+	echo "$result"
+	return 0
 }
 
-checkbootparam(){
-case "$CMDLINE" in *\ $1*) return 0;; esac
-return 1
+checkbootparam()
+{
+	case "$CMDLINE" in *\ $1*) return 0;; esac
+	return 1
 }
 
-# Read in what hwsetup has found for X
+
+# < Read in what hwsetup has found for X >
 [ -f /etc/sysconfig/mol/xserver ] && . /etc/sysconfig/mol/xserver
 
-# Xserver, Xmodule, Xscreen, Xvrefresh, if specified by commandline
+# < Xserver, Xmodule, Xscreen, Xvrefresh, if specified by commandline >
 NEWXSERVER="$(getbootparam xserver 2>/dev/null)"
 [ -z "$XSERVER" -a -z "$NEWXSERVER" ] && NEWXSERVER="XFree86"
 [ -n "$NEWXSERVER" ] && { XSERVER="$NEWXSERVER" ; echo "XSERVER='$XSERVER'" >> /etc/sysconfig/mol/mol ; echo "XSERVER='$XSERVER'" >> /etc/sysconfig/mol/xserver; }
@@ -75,37 +84,43 @@ XHREFRESH="$(getbootparam xhrefresh 2>/dev/null)"
 XDEPTH="$(getbootparam xdepth 2>/dev/null)"
 [ -n "$XDEPTH" ] || XDEPTH="$(getbootparam depth 2>/dev/null)"
 [ -n "$XDEPTH" ] && { echo "XDEPTH='$XDEPTH'" >> /etc/sysconfig/mol/mol ; echo "XDEPTH='$XDEPTH'" >> /etc/sysconfig/mol/xserver; }
+
 # Wheel
 WHEEL=""
 if checkbootparam "wheel"; then
 WHEEL='s|"PS/2"|"IMPS/2"\
-Option          "ZAxisMapping"          "4 5"|g;'
+	Option		"ZAxisMapping"		"4 5"|g;'
 elif checkbootparam "nowheel"; then
 # Don't change the default, which is plain PS/2
 WHEEL=""
 else
 # Apparently, the mouse auto-protocol option works in XFree 4.3 now. Let's give it a try.
 WHEEL='s|"PS/2"|"auto"\
-Option          "ZAxisMapping"          "4 5"|g;'
+	Option		"ZAxisMapping"		"4 5"|g;'
 fi
 
-# Read in changes
+
+# < Read in changes >
 [ -f /etc/sysconfig/mol/mol ] && . /etc/sysconfig/mol/mol
 
 # Read default keyboard from config file.
 # There seems to be no reliable autoprobe possible.
 [ -f /etc/sysconfig/mol/keyboard ] && . /etc/sysconfig/mol/keyboard
 
-# Create mouse link and insert a mouse default type into XF86Config
+
+# < Create mouse link and insert a mouse default type into XF86Config >
 # if not already done by hwsetup
 [ -f /etc/sysconfig/mol/mouse ] && . /etc/sysconfig/mol/mouse
-[ -e /dev/mouse ] || ln -sf /dev/ttyS0 /dev/mouse
+##[ -e /dev/mouse ] || ln -sf /dev/ttyS0 /dev/mouse
 # PROTO="${XMOUSETYPE:-Auto}"
 PROTO="${XMOUSETYPE:-Microsoft}"
+
 NOEMU=""
 [ "${XEMU3}" = "no" ] && NOEMU='s|^.*Emulate3|# No 2 -> 3 Button emulation|g'
+
 DEADKEYS=""
 [ "$XKEYBOARD" = "de" ] || DEADKEYS='s|^.*nodeadkeys.*$||g;'
+
 if [ -n "XMODULE" ]; then
 # Check for Framebuffer X-Modules and initialize framebuffer module
 case "$XMODULE" in
@@ -113,6 +128,8 @@ pvr2fb) modprobe "$XMODULE" >/dev/null 2>&1 ; XMODULE="fbdev"; ;;
 esac
 fi
 
+
+# < Try to get Monitor data via ddcxinfo-berry >
 NODDC=""
 checkbootparam noddc &&  NODDC="true"
 
@@ -121,7 +138,6 @@ COMPLETE=""
 RC=""
 
 if [ -z "$NODDC" ]; then
-# Try to get Monitor data via ddcxinfo-mol
 MONITOR="$(ddcxinfo-mol -monitor)"
 RC="$?"
 COMPLETE="$(awk '/EndSection/{print}' <<EOF
@@ -317,7 +333,7 @@ DEPTH='s|DefaultColorDepth[	].*$|DefaultColorDepth '"$XDEPTH"'|g;'
 fi
 
 # We need to check this because serial mice have long timeouts
-#SERIALMOUSE="$(ls -l1 /dev/mouse* 2>/dev/null | awk '/ttyS/{print $NF ; exit 0}')"
+##SERIALMOUSE="$(ls -l1 /dev/mouse* 2>/dev/null | awk '/ttyS/{print $NF ; exit 0}')"
 SERIALMOUSE="$(echo $MOUSE_DEVICE | grep /tts/)"
 if [ -n "$SERIALMOUSE" ]; then
 SERIALMOUSE="s|/dev/ttyS0|$SERIALMOUSE|g;"
@@ -326,7 +342,7 @@ SERIALMOUSE='s|^.*InputDevice.*"Serial Mouse".*$|# Serial Mouse not detected|g;'
 fi
 
 # PS/2 bug: Some keyboards are incorrectly used as mice in XFree. :-(
-#PSMOUSE="$(ls -l1 /dev/mouse* 2>/dev/null | awk '/psaux/{print $NF ; exit 0}')"
+##PSMOUSE="$(ls -l1 /dev/mouse* 2>/dev/null | awk '/psaux/{print $NF ; exit 0}')"
 PSMOUSE="$(echo $MOUSE_DEVICE | grep /psaux)"
 if [ -n "$PSMOUSE" ]; then
 PSMOUSE=""
@@ -360,36 +376,28 @@ esac
 rm -f "$MONITORTMP"
 echo "$MONITOR" >"$MONITORTMP"
 
-## /etc/X11/XF86Config* is the "default" config.
-#if [ ! -f /etc/XF86Config -a ! -f /etc/X11/XF86Config ]; then
-## Remove it, just in case it's a link to CD
-#rm -f /etc/XF86Config /etc/X11/XF86Config 2>/dev/null
-#sed -e 's|@@PROTOCOL@@|'"$PROTO"'|g;'"$NOEMU" \
-#    -e '/@@MONITOR@@/r '"$MONITORTMP" \
-#    -e 's|@@MONITOR@@||g' \
-#    -e 's|@@MODES@@|'"$MODES"'|g;'"$DEPTH" \
-#    -e 's|XkbLayout *"[^"]*"|XkbLayout "'"$XKEYBOARD"'"|g;'"$DEADKEYS" \
-#    /etc/X11/XF86Config.in > /etc/X11/XF86Config
-#fi
-
-if [ ! -f /etc/xorg.conf -a ! -f /etc/X11/xorg.conf ]; then 
-rm -f /etc/xorg.conf /etc/X11/xorg.conf 2>/dev/null
+# /etc/X11/xorg.conf is the "default" config.
+xorgconf=xorg.conf
+#xorgconf=XF86Config
+if [ ! -f /etc/${xorgconf} -a ! -f /etc/X11/${xorgconf} ]; then
+# Remove it, just in case it's a link to CD
+rm -f /etc/${xorgconf} /etc/X11/${xorgconf} 2>/dev/null
 
 # VMWare special handling
 VMWARE=""
 if [ "$XMODULE" = "vmware" ]; then
-VMWARE='s|^.*BusID.*PCI.*$|BusID "PCI:0:15:0"|g;'
-DEPTH='s|DefaultColorDepth |# DefaultColorDepth |g;'
+	VMWARE='s|^.*BusID.*PCI.*$|BusID "PCI:0:15:0"|g;'
+	DEPTH='s|DefaultColorDepth|#DefaultColorDepth|g;'
 fi
 
 # Do NOT use a default colordepth setting if we are using the "fbdev" module
 if [ "$XMODULE" = "fbdev" ]; then
-DEPTH='s|DefaultColorDepth |# DefaultColorDepth |g;'
+	DEPTH='s|DefaultColorDepth|#DefaultColorDepth|g;'
 fi
 
 # These drivers need the sw_cursor option
 SWCURSOR=""
-case "$XMODULE" in ati|radeon|nv|trident) SWCURSOR='s|^.*#Option.*"sw_cursor".*$|Option "sw_cursor"|g;';; esac
+case "$XMODULE" in ati|radeon|nv|trident) SWCURSOR='s|^.*#Option.*"sw_cursor".*$|	Option	"sw_cursor"|g;';; esac
 
 # We must use NoPM, because some machines freeze if Power management is being activated.
 
@@ -403,20 +411,21 @@ sed -e 's|@@PROTOCOL@@|'"$PROTO"'|g;'"$NOEMU" \
     -e 's|@@NOPM@@|'"$NOPM"'|g' \
     -e 's|@@XMODULE@@|'"$XMODULE"'|g;'"$VMWARE""$SERIALMOUSE""$USBMOUSE""$PSMOUSE""$SWCURSOR""$WHEEL" \
     -e 's|@@MODES@@|'"$MODES"'|g;'"$DEPTH" \
-    -e 's|"XkbLayout" *"[^"]*"|"XkbLayout" "'"$XKEYBOARD"'"|g;'"$DEADKEYS" \
-    /etc/X11/xorg.conf.in >/etc/X11/xorg.conf
+    -e 's|"XkbLayout".*"[^"]*"|"XkbLayout"\t\t"'"$XKEYBOARD"'"|g;'"$DEADKEYS" \
+    ${xsetdir}/${xorgconf}.in >/etc/X11/${xorgconf}
 
 if [ -n "$DPMS" ]; then
 sed -e 's|Identifier[	 ]*"Monitor0"|Identifier	"Monitor0"\
-	'"$DPMS"'|g' /etc/X11/xorg.conf >/etc/X11/xorg.conf.new
-mv -f /etc/X11/xorg.conf.new /etc/X11/xorg.conf
+	'"$DPMS"'|g' /etc/X11/${xorgconf} >/etc/X11/${xorgconf}.new
+mv -f /etc/X11/${xorgconf}.new /etc/X11/${xorgconf}
 fi
 
 fi
 
 rm -f "$TMPFILE" "$MONITORTMP" 2>/dev/null
 
-# Print info about selected X-Server
+
+# < Print info about selected X-Server >
 [ -n "$XDESC" ] || XDESC="(yet) unknown card"
 echo -n " ${GREEN}Video is"
 [ -n "$XDESC" ] && echo -n " ${YELLOW}$XDESC${GREEN},"
