@@ -4,7 +4,7 @@
  *
  * Heavily modified by Manuel Novoa III       Mar 12, 2001
  *
- * Version:     $Id: inet_common.h,v 1.1.1.1 2006/01/07 11:16:48 dgel Exp $
+ * Version:     $Id: inet_common.h,v 1.1.1.2 2006/02/25 01:18:09 dgel Exp $
  *
  */
 
@@ -29,7 +29,5 @@ extern int INET_resolve(const char *name, struct sockaddr_in *s_in, int hostfirs
 extern int INET_rresolve(char *name, size_t len, struct sockaddr_in *s_in,
 			 int numeric, unsigned int netmask);
 
-#ifdef CONFIG_FEATURE_IPV6
 extern int INET6_resolve(const char *name, struct sockaddr_in6 *sin6);
 extern int INET6_rresolve(char *name, size_t len, struct sockaddr_in6 *sin6, int numeric);
-#endif
