@@ -24,9 +24,6 @@
 #include <arpa/inet.h>
 #include <netdb.h>
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
 #include <getopt.h>
 
 #include "busybox.h"
@@ -117,9 +114,9 @@ static char *safe_fgets(char *s, int size, FILE *stream)
 /*
  *  Base64-encode character string
  *  oops... isn't something similar in uuencode.c?
- *  It would be better to use already existing code
+ *  XXX: It would be better to use already existing code
  */
-char *base64enc(unsigned char *p, char *buf, int len) {
+static char *base64enc(unsigned char *p, char *buf, int len) {
 
         char al[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
                     "0123456789+/";
@@ -177,23 +174,25 @@ int wget_main(int argc, char **argv)
 	struct sockaddr_in s_in;
 	llist_t *headers_llist = NULL;
 
-	FILE *sfp = NULL;			/* socket to web/ftp server			*/
-	FILE *dfp = NULL;			/* socket to ftp server (data)		*/
-	char *fname_out = NULL;		/* where to direct output (-O)		*/
-	int do_continue = 0;		/* continue a prev transfer (-c)	*/
-	long beg_range = 0L;		/*   range at which continue begins	*/
-	int got_clen = 0;			/* got content-length: from server	*/
-	FILE *output;				/* socket to web server				*/
-	int quiet_flag = FALSE;		/* Be verry, verry quiet...			*/
-	int use_proxy = 1;          /* Use proxies if env vars are set  */
+	FILE *sfp = NULL;		/* socket to web/ftp server	    */
+	FILE *dfp = NULL;		/* socket to ftp server (data)	    */
+	char *fname_out = NULL;		/* where to direct output (-O)	    */
+	int do_continue = 0;		/* continue a prev transfer (-c)    */
+	long beg_range = 0L;		/*   range at which continue begins */
+	int got_clen = 0;		/* got content-length: from server  */
+	FILE *output;			/* socket to web server		    */
+	int quiet_flag = FALSE;		/* Be verry, verry quiet...	    */
+	int use_proxy = 1;		/* Use proxies if env vars are set  */
 	char *proxy_flag = "on";	/* Use proxies if env vars are set  */
 
 	/*
 	 * Crack command line.
 	 */
-	bb_opt_complementaly = "\203*";
+	bb_opt_complementally = "-1:\203::";
 	bb_applet_long_options = wget_long_options;
-	opt = bb_getopt_ulflags(argc, argv, "cq\213O:\203:P:Y:", &fname_out, &headers_llist, &dir_prefix, &proxy_flag);
+	opt = bb_getopt_ulflags(argc, argv, "cq\213O:\203:P:Y:", 
+					&fname_out, &headers_llist, 
+					&dir_prefix, &proxy_flag);
 	if (opt & WGET_OPT_CONTINUE) {
 		++do_continue;
 	}
@@ -218,9 +217,7 @@ int wget_main(int argc, char **argv)
 			headers_llist = headers_llist->link;
 		}
 	}
-	if (argc - optind != 1)
-			bb_show_usage();
-
+	
 	parse_url(argv[optind], &target);
 	server.host = target.host;
 	server.port = target.port;
@@ -854,7 +851,7 @@ progressmeter(int flag)
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *	$Id: wget.c,v 1.1.1.1 2006/01/07 11:16:57 dgel Exp $
+ *	$Id: wget.c,v 1.1.1.2 2006/02/25 01:18:19 dgel Exp $
  */
 
 
